@@ -3,5 +3,5 @@
 import pickle
 f = open('test.pck' , 'r')
 x = pickle.load(f)
-print x , type(x)        # check the type of data read
+print( x , type(x) )       # check the type of data read
 f.close()
