@@ -3,8 +3,8 @@
 x = 1
 while x < 11:
     if x < 5:
-        print 'Samll ', x
+        print( 'Samll ', x)
     else:
-        print 'Big ', x
+        print( 'Big ', x)
     x = x + 1
-print 'Done'
+print( 'Done')
