@@ -2,5 +2,5 @@ from numpy import *
 x = arange(0, 3, 1)
 y = arange(0, 3, 1)
 gx, gy = meshgrid(x, y)
-print gx
-print gy
+print( gx)
+print( gy)
